@@ -14,12 +14,33 @@
 
 from __future__ import annotations
 
+from types import ModuleType
+
+from nox import project
+from nox._cli import main
 from nox._options import noxfile_options as options
-from nox._parametrize import Param as param
+from nox._parametrize import Param as param  # noqa: N813
 from nox._parametrize import parametrize_decorator as parametrize
 from nox.registry import session_decorator as session
 from nox.sessions import Session
 
 needs_version: str | None = None
 
-__all__ = ["needs_version", "parametrize", "param", "session", "options", "Session"]
+__all__ = [
+    "Session",
+    "main",
+    "needs_version",
+    "options",
+    "param",
+    "parametrize",
+    "project",
+    "session",
+]
+
+
+def __dir__() -> list[str]:
+    # Only nox modules are imported here, so we can safely use globals() to
+    # find nox modules only. Other modules, like types and __future__, are imported
+    # from, so don't populate the module globals with surprising entries.
+    modules = {k for k, v in globals().items() if isinstance(v, ModuleType)}
+    return sorted(set(__all__) | modules)
