@@ -14,53 +14,71 @@
 
 from __future__ import annotations
 
-import collections
 import copy
 import functools
-from collections.abc import Sequence
-from typing import Any, Callable, TypeVar, overload
+import warnings
+from typing import TYPE_CHECKING, Any, Callable, Literal, overload
 
 from ._decorators import Func
-from ._typing import Python
 
-F = TypeVar("F", bound=Callable[..., Any])
+if TYPE_CHECKING:
+    from collections.abc import Sequence
 
-_REGISTRY: collections.OrderedDict[str, Func] = collections.OrderedDict()
+    from ._typing import Python
+
+__all__ = ["get", "reset", "session_decorator"]
+
+
+def __dir__() -> list[str]:
+    return __all__
+
+
+RawFunc = Callable[..., Any]
+
+_REGISTRY: dict[str, Func] = {}
+
+
+def reset() -> None:
+    _REGISTRY.clear()
 
 
 @overload
-def session_decorator(__func: F) -> F:
-    ...
+def session_decorator(func: RawFunc | Func, /) -> Func: ...
 
 
 @overload
 def session_decorator(
-    __func: None = ...,
+    func: None = ...,
+    /,
     python: Python | None = ...,
     py: Python | None = ...,
-    reuse_venv: bool | None = ...,
+    reuse_venv: bool | None = ...,  # noqa: FBT001
     name: str | None = ...,
-    venv_backend: Any | None = ...,
-    venv_params: Any | None = ...,
+    venv_backend: str | None = ...,
+    venv_params: Sequence[str] = ...,
     tags: Sequence[str] | None = ...,
     *,
     default: bool = ...,
-) -> Callable[[F], F]:
-    ...
+    requires: Sequence[str] | None = ...,
+    download_python: Literal["auto", "never", "always"] | None = None,
+) -> Callable[[RawFunc | Func], Func]: ...
 
 
 def session_decorator(
-    func: F | None = None,
+    func: Callable[..., Any] | Func | None = None,
+    /,
     python: Python | None = None,
     py: Python | None = None,
-    reuse_venv: bool | None = None,
+    reuse_venv: bool | None = None,  # noqa: FBT001
     name: str | None = None,
-    venv_backend: Any | None = None,
-    venv_params: Any | None = None,
+    venv_backend: str | None = None,
+    venv_params: Sequence[str] = (),
     tags: Sequence[str] | None = None,
     *,
     default: bool = True,
-) -> F | Callable[[F], F]:
+    requires: Sequence[str] | None = None,
+    download_python: Literal["auto", "never", "always"] | None = None,
+) -> Func | Callable[[RawFunc | Func], Func]:
     """Designate the decorated function as a session."""
     # If `func` is provided, then this is the decorator call with the function
     # being sent as part of the Python syntax (`@nox.session`).
@@ -80,18 +98,22 @@ def session_decorator(
             venv_params=venv_params,
             tags=tags,
             default=default,
+            requires=requires,
+            download_python=download_python,
         )
 
     if py is not None and python is not None:
-        raise ValueError(
+        msg = (
             "The py argument to nox.session is an alias for the python "
             "argument, please only specify one."
         )
+        raise ValueError(msg)
 
     if python is None:
         python = py
 
     final_name = name or func.__name__
+
     fn = Func(
         func,
         python,
@@ -101,12 +123,22 @@ def session_decorator(
         venv_params,
         tags=tags,
         default=default,
+        requires=requires,
+        download_python=download_python,
     )
-    _REGISTRY[final_name] = fn
+    reg_name = name or func.__name__
+    if reg_name in _REGISTRY:
+        msg = (
+            f"The session {reg_name!r} has already been registered; "
+            "this will be an error in a future version of nox. "
+            "Overriding the old session for now."
+        )
+        warnings.warn(msg, FutureWarning, stacklevel=2)
+    _REGISTRY[reg_name] = fn
     return fn
 
 
-def get() -> collections.OrderedDict[str, Func]:
+def get() -> dict[str, Func]:
     """Return a shallow copy of the registry.
 
     This ensures that the registry is not accidentally modified by
