@@ -14,8 +14,8 @@
 
 from __future__ import annotations
 
-from pathlib import Path
 from textwrap import dedent
+from typing import TYPE_CHECKING
 
 import pytest
 
@@ -28,12 +28,16 @@ from nox._version import (
     get_nox_version,
 )
 
+if TYPE_CHECKING:
+    from collections.abc import Callable
+    from pathlib import Path
+
 
 @pytest.fixture
-def temp_noxfile(tmp_path: Path):
+def temp_noxfile(tmp_path: Path) -> Callable[[str], str]:
     def make_temp_noxfile(content: str) -> str:
         path = tmp_path / "noxfile.py"
-        path.write_text(content)
+        path.write_text(content, encoding="utf8")
         return str(path)
 
     return make_temp_noxfile
@@ -47,12 +51,12 @@ def test_needs_version_default() -> None:
 def test_get_nox_version() -> None:
     """It returns something that looks like a Nox version."""
     result = get_nox_version()
-    year, month, day, *_ = (int(part) for part in result.split("."))
+    year, _month, _day, *_ = (int(part) for part in result.split("."))
     assert year >= 2020
 
 
 @pytest.mark.parametrize(
-    "text,expected",
+    ("text", "expected"),
     [
         ("", None),
         (
@@ -100,7 +104,9 @@ def test_parse_needs_version(text: str, expected: str | None) -> None:
 
 
 @pytest.mark.parametrize("specifiers", ["", ">=2020.12.31", ">=2020.12.31,<9999.99.99"])
-def test_check_nox_version_succeeds(temp_noxfile, specifiers: str) -> None:
+def test_check_nox_version_succeeds(
+    temp_noxfile: Callable[[str], str], specifiers: str
+) -> None:
     """It does not raise if the version specifiers are satisfied."""
     text = dedent(
         f"""
@@ -112,7 +118,9 @@ def test_check_nox_version_succeeds(temp_noxfile, specifiers: str) -> None:
 
 
 @pytest.mark.parametrize("specifiers", [">=9999.99.99"])
-def test_check_nox_version_fails(temp_noxfile, specifiers: str) -> None:
+def test_check_nox_version_fails(
+    temp_noxfile: Callable[[str], str], specifiers: str
+) -> None:
     """It raises an exception if the version specifiers are not satisfied."""
     text = dedent(
         f"""
@@ -125,7 +133,9 @@ def test_check_nox_version_fails(temp_noxfile, specifiers: str) -> None:
 
 
 @pytest.mark.parametrize("specifiers", ["invalid", "2020.12.31"])
-def test_check_nox_version_invalid(temp_noxfile, specifiers: str) -> None:
+def test_check_nox_version_invalid(
+    temp_noxfile: Callable[[str], str], specifiers: str
+) -> None:
     """It raises an exception if the version specifiers cannot be parsed."""
     text = dedent(
         f"""
